@@ -1,6 +1,6 @@
 import os
 
-from .models.db import parse_uri
+from .models._conn import parse_uri
 
 from .models import Addresses
 from .models import Users
@@ -31,5 +31,5 @@ def get_db():
     This is an object which contains the database connection, `.connection`, and
     a cursor for executing SQL queries, `.cursor`.
     """
-    from .models.db import DatabaseConnection
+    from .models._conn import DatabaseConnection
     return DatabaseConnection.get_instance()
