@@ -9,30 +9,28 @@ class AddressModelDecorator:
 
     @property
     def address(self):
-        assert self.__dict__.get("address_num") is not None
+        assert self.__dict__.get("address_zip") is not None
 
         address_keys = {
-            "num": self.address_num,
-            "street": self.address_street,
-            "apt": self.address_apt,
+            "line_1": self.address_line_1,
+            "line_2": self.address_line_2,
             "zip": self.address_zip
         }
         return Addresses.get(address_keys)
 
 class Addresses(Models):
     table_name = "addresses"
-    table_primaries = ["num", "street", "apt", "zip"]
+    table_primaries = ["line_1", "line_2", "zip"]
 
     def __init__(self, db_data):
-        self.num = db_data["num"]
-        self.street = db_data["street"]
-        self.apt = db_data["apt"]
+        self.line_1 = db_data["line_1"]
+        self.line_2 = db_data["line_2"]
         self.city = db_data["city"]
         self.state = db_data["state"]
         self.zip = db_data["zip"]
 
     def display(self):
-        return f"{self.num} {self.street}, {self.city}, {self.state} {self.zip}"
+        return f"{self.line_1} {self.line_2},{self.city} {self.state} {self.zip}"
 
     def region(self):
         return f"{self.city}, {self.state}"
